---------------------------------------------------------------------------
--! @file   dsk_mex_hrsc.lua
--! @brief  FLOW configuration example (DSK Type02 Example)
--! @copyright Copyright 2010-2012 Japan Aerospace Exploration Agency
--
--
-- DSK Type02 (MEX HRSC SRC)
--
-- Overview
--
-- This examples shows the simulation of Phobos image taken by
-- Mars Express HRSC SRC at 2006-01-20T23:07:49.000. 
-- This example uses SPICE DSK Type 2 as a shape model.
-- Refer to Sub-Mars to trailing side of Phobos.
-- Rotate the simulated image 90 degrees anticlockwise to compare.
--
-- Notice
--
-- Experimental support for SPICE DSK Type 2 (a shape model format).
-- To run this example, use alpha_dsk_c instead of normal cspice.
--
-- Reference
--   http://www.planetary.org/blogs/emily-lakdawalla/2008/1398.html
--   http://pds-geosciences.wustl.edu/mex/mex-m-hrsc-3-rdr-v2/mexhrsc_0001/browse/2601/h2601_0006_sr2.jpg
--
---------------------------------------------------------------------------


--
-- Kernel directories
--
generic_kernel_dir = "kernels/generic_kernels/"
mex_kernel_dir = "kernels/MEX/"

--
-- Spice kernels.
--
spice_kernels = {
   generic_kernel_dir .. "lsk/naif0010.tls",
   generic_kernel_dir .. "pck/pck00010.tpc",
   generic_kernel_dir .. "spk/planets/de421.bsp",
   -- MEX
   mex_kernel_dir .. "SCLK/MEX_101019_STEP.TSC",
   mex_kernel_dir .. "FK/MEX_V10.TF",
   mex_kernel_dir .. "IK/MEX_HRSC_V04.TI",
   mex_kernel_dir .. "SPK/ORMM__060101000000_00217.BSP",
   mex_kernel_dir .. "CK/ATNM_P050401000000_00260.BC",
}


--
-- satellite data
--
satellite_kernel_dir = generic_kernel_dir .. "spk/satellites/"
satellite_kernels = {
   satellite_kernel_dir .. "mar085.bsp",
}

--
-- star data
--
star_kernel = generic_kernel_dir .. "stars/hipparcos.bdb"
star_magnitude_limit = 4.0

texture_file_dir = "texture/"
model_file_dir   = "models/"

--
-- texture/model table
--
object_table = {
   ["SATELLITE.PHOBOS"] = {
	  {type       = "model",
	   file = model_file_dir .. "phobos512.bds",
	   scale = 1.0,
	   color = "230,230,230",
	   format = "DSK"}
   }
}

--
-- output objects
--
output_objects = {
  "STARS",
  "SATELLITE.PHOBOS",
}

--
-- view settings.
--
title = "Simulation of Phobos taken by MEX SRC"
basis_object = "Mars Express"
basis_instrument_id = -41220
aberration_correction = "LT+S"

--
-- image size
--
image_width  = 512
image_height = 512

time = "2006-01-20T23:07:49.000"

--end of file
